CurtainSide enum

The target direction or boundary edge of the screen canvas from which a curtain pull gesture originates.

Inheritance
Available extensions

Values

left → const CurtainSide

Deploys the curtain fold beginning at the left screen boundary.

Deploys the curtain fold beginning at the right screen boundary.

top → const CurtainSide

Deploys the curtain fold beginning at the top screen boundary.

bottom → const CurtainSide

Deploys the curtain fold beginning at the bottom screen boundary.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CurtainSide>
A constant List of the values in this enum, in order of their declaration.